==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/WplataPlikPozycja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class WplataPlikPozycja extends GenericDPSObject {
    /**
     * WPLATA_PLIK_POZYCJA.POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pozycjaId;

    /**
     * WPLATA_PLIK_POZYCJA.PLIK_CSV_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long plikCsvId;

    /**
     * WPLATA_PLIK_POZYCJA.WIERSZ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer wiersz;

    /**
     * WPLATA_PLIK_POZYCJA.TRESC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String tresc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return WPLATA_PLIK_POZYCJA.POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPozycjaId() {
        return pozycjaId;
    }

    /**
     * WPLATA_PLIK_POZYCJA.POZYCJA_ID
     *
     * @param pozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPozycjaId(Long pozycjaId) {
        this.pozycjaId = pozycjaId;
    }

    /**
     * @return WPLATA_PLIK_POZYCJA.PLIK_CSV_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPlikCsvId() {
        return plikCsvId;
    }

    /**
     * WPLATA_PLIK_POZYCJA.PLIK_CSV_ID
     *
     * @param plikCsvId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPlikCsvId(Long plikCsvId) {
        this.plikCsvId = plikCsvId;
    }

    /**
     * @return WPLATA_PLIK_POZYCJA.WIERSZ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getWiersz() {
        return wiersz;
    }

    /**
     * WPLATA_PLIK_POZYCJA.WIERSZ
     *
     * @param wiersz
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWiersz(Integer wiersz) {
        this.wiersz = wiersz;
    }

    /**
     * @return WPLATA_PLIK_POZYCJA.TRESC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTresc() {
        return tresc;
    }

    /**
     * WPLATA_PLIK_POZYCJA.TRESC
     *
     * @param tresc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTresc(String tresc) {
        this.tresc = tresc == null ? null : tresc.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        WplataPlikPozycja other = (WplataPlikPozycja) that;
        return (this.getPozycjaId() == null ? other.getPozycjaId() == null : this.getPozycjaId().equals(other.getPozycjaId()))
            && (this.getPlikCsvId() == null ? other.getPlikCsvId() == null : this.getPlikCsvId().equals(other.getPlikCsvId()))
            && (this.getWiersz() == null ? other.getWiersz() == null : this.getWiersz().equals(other.getWiersz()))
            && (this.getTresc() == null ? other.getTresc() == null : this.getTresc().equals(other.getTresc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPozycjaId() == null) ? 0 : getPozycjaId().hashCode());
        result = prime * result + ((getPlikCsvId() == null) ? 0 : getPlikCsvId().hashCode());
        result = prime * result + ((getWiersz() == null) ? 0 : getWiersz().hashCode());
        result = prime * result + ((getTresc() == null) ? 0 : getTresc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", pozycjaId=").append(pozycjaId);
        sb.append(", plikCsvId=").append(plikCsvId);
        sb.append(", wiersz=").append(wiersz);
        sb.append(", tresc=").append(tresc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/WplataPlikPozycja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class WplataPlikPozycja extends GenericDPSObject {
    /**
     * WPLATA_PLIK_POZYCJA.POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pozycjaId;

    /**
     * WPLATA_PLIK_POZYCJA.PLIK_CSV_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long plikCsvId;

    /**
     * WPLATA_PLIK_POZYCJA.WIERSZ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer wiersz;

    /**
     * WPLATA_PLIK_POZYCJA.TRESC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String tresc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return WPLATA_PLIK_POZYCJA.POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPozycjaId() {
        return pozycjaId;
    }

    /**
     * WPLATA_PLIK_POZYCJA.POZYCJA_ID
     *
     * @param pozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPozycjaId(Long pozycjaId) {
        this.pozycjaId = pozycjaId;
    }

    /**
     * @return WPLATA_PLIK_POZYCJA.PLIK_CSV_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPlikCsvId() {
        return plikCsvId;
    }

    /**
     * WPLATA_PLIK_POZYCJA.PLIK_CSV_ID
     *
     * @param plikCsvId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPlikCsvId(Long plikCsvId) {
        this.plikCsvId = plikCsvId;
    }

    /**
     * @return WPLATA_PLIK_POZYCJA.WIERSZ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getWiersz() {
        return wiersz;
    }

    /**
     * WPLATA_PLIK_POZYCJA.WIERSZ
     *
     * @param wiersz
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWiersz(Integer wiersz) {
        this.wiersz = wiersz;
    }

    /**
     * @return WPLATA_PLIK_POZYCJA.TRESC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTresc() {
        return tresc;
    }

    /**
     * WPLATA_PLIK_POZYCJA.TRESC
     *
     * @param tresc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTresc(String tresc) {
        this.tresc = tresc == null ? null : tresc.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        WplataPlikPozycja other = (WplataPlikPozycja) that;
        return (this.getPozycjaId() == null ? other.getPozycjaId() == null : this.getPozycjaId().equals(other.getPozycjaId()))
            && (this.getPlikCsvId() == null ? other.getPlikCsvId() == null : this.getPlikCsvId().equals(other.getPlikCsvId()))
            && (this.getWiersz() == null ? other.getWiersz() == null : this.getWiersz().equals(other.getWiersz()))
            && (this.getTresc() == null ? other.getTresc() == null : this.getTresc().equals(other.getTresc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPozycjaId() == null) ? 0 : getPozycjaId().hashCode());
        result = prime * result + ((getPlikCsvId() == null) ? 0 : getPlikCsvId().hashCode());
        result = prime * result + ((getWiersz() == null) ? 0 : getWiersz().hashCode());
        result = prime * result + ((getTresc() == null) ? 0 : getTresc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", pozycjaId=").append(pozycjaId);
        sb.append(", plikCsvId=").append(plikCsvId);
        sb.append(", wiersz=").append(wiersz);
        sb.append(", tresc=").append(tresc);
        sb.append("]");
        return sb.toString();
    }
}
